gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r33949 - gnunet/src/gns


From: gnunet
Subject: [GNUnet-SVN] r33949 - gnunet/src/gns
Date: Thu, 10 Jul 2014 12:38:46 +0200

Author: wachs
Date: 2014-07-10 12:38:46 +0200 (Thu, 10 Jul 2014)
New Revision: 33949

Modified:
   gnunet/src/gns/gnunet-service-gns.c
Log:
rename "name" to label


Modified: gnunet/src/gns/gnunet-service-gns.c
===================================================================
--- gnunet/src/gns/gnunet-service-gns.c 2014-07-10 09:15:05 UTC (rev 33948)
+++ gnunet/src/gns/gnunet-service-gns.c 2014-07-10 10:38:46 UTC (rev 33949)
@@ -503,21 +503,21 @@
  *
  * @param cls the closure (NULL)
  * @param key the private key of the authority (ours)
  * @param name the name of the records, NULL once the iteration is done
  * @param rd_count the number of records in @a rd
  * @param rd the record data
  */
 static void
 put_gns_record (void *cls,
                 const struct GNUNET_CRYPTO_EcdsaPrivateKey *key,
-                const char *name,
+                const char *label,
                 unsigned int rd_count,
                 const struct GNUNET_GNSRECORD_Data *rd)
 {
   struct GNUNET_GNSRECORD_Data rd_public[rd_count];
   unsigned int rd_public_count;
 
-  if (NULL == name)
+  if (NULL == label)
   {
     /* we're done with one iteration, calculate when to do the next one */
     namestore_iter = NULL;
@@ -588,7 +588,7 @@
   }
 
   active_put = perform_dht_put (key,
-                                name,
+                                label,
                                 rd_public,
                                 rd_public_count,
                                 NULL);
@@ -503,21 +503,21 @@
  * @param cls the closure (NULL)
  * @param key the private key of the authority (ours)
- * @param name the name of the records, NULL once the iteration is done
+ * @param label the name of the records, NULL once the iteration is done
  * @param rd_count the number of records in @a rd
  * @param rd the record data




reply via email to

[Prev in Thread] Current Thread [Next in Thread]